@@ -15,9 +15,6 @@
 #' if (!cqp_is_initialized()) cqp_initialize()
 #' cqp_is_initialized() # check initialization status (TRUE now?)
 #' cqp_get_registry() # get registry dir used by CQP
-#' 
-#' registry <- if (!check_pkg_registry_files()) use_tmp_registry() else get_pkg_registry()
-#' if (cqp_get_registry() != registry) cqp_reset_registry(registry = registry)
 #' cqp_list_corpora() # get list of corpora
 cqp_initialize <- function(registry = Sys.getenv("CORPUS_REGISTRY")){
   registry_new <- registry
@@ -60,9 +57,19 @@ cqp_is_initialized <- function(){
   if (.cqp_get_status() == 0) return(FALSE) else return(TRUE)
 }
 
+#' @param silent A single `logical` value, whether to be silent and suppress CQP
+#'   messages (`TRUE`), or not (`FALSE`).
+#' @param verbose A single `logical` value, whether to show verbose parser
+#'   output (`TRUE`) or not (`FALSE`).
+#' @export cqp_verbosity
+#' @rdname cqp_initialize
+cqp_verbosity <- function(silent, verbose){
+  .cqp_verbosity(quietly = silent, verbose = verbose)
+}
+
 #' @export cqp_get_registry
 #' @rdname cqp_initialize
-cqp_get_registry <- function() .cqp_get_registry()
+cqp_get_registry <- function() fs::path(.cqp_get_registry())
 
 #' @export cqp_reset_registry
 #' @rdname cqp_initialize
@@ -74,7 +81,7 @@ cqp_reset_registry <- function(registry = Sys.getenv("CORPUS_REGISTRY")){
   } else {
     check_registry(registry_dir)
     Sys.setenv(CORPUS_REGISTRY = registry_dir)
-    if (nchar(registry_dir) > 255){
+    if (nchar(registry_dir) > 255L){
       stop("cannot assign new registry: maximum nchar(registry) is 255")
     } else {
       .cqp_set_registry(registry_dir = registry_dir)
@@ -91,10 +98,6 @@ cqp_reset_registry <- function(registry = Sys.getenv("CORPUS_REGISTRY")){
 #' 
 #' @export cqp_list_corpora
 #' @examples
-#' if (!cqp_is_initialized()){
-#'   registry <- system.file(package = "RcppCWB", "extdata", "cwb", "registry")
-#'   cqp_initialize(registry)
-#' }
 #' cqp_list_corpora()
 #' @author Andreas Blaette, Bernard Desgraupes, Sylvain Loiseau
 cqp_list_corpora <- function() .cqp_list_corpora()
@@ -120,13 +123,6 @@ cqp_list_corpora <- function() .cqp_list_corpora()
 #' Evert, S. 2005. The CQP Query Language Tutorial. Available online at
 #' \url{https://cwb.sourceforge.io/files/CWB_Encoding_Tutorial.pdf}
 #' @examples 
-#' registry <- if (!check_pkg_registry_files()) use_tmp_registry() else get_pkg_registry()
-#' 
-#' if (!cqp_is_initialized()){
-#'   cqp_initialize(registry = registry)
-#' } else {
-#'   if (cqp_get_registry() != registry) cqp_reset_registry(registry)
-#' }
 #' cqp_query(corpus = "REUTERS", query = '"oil";')
 #' cqp_subcorpus_size("REUTERS")
 #' cqp_dump_subcorpus("REUTERS")
@@ -136,8 +132,8 @@ cqp_list_corpora <- function() .cqp_list_corpora()
 #' cqp_dump_subcorpus("REUTERS")
 #' @author Andreas Blaette, Bernard Desgraupes, Sylvain Loiseau
 cqp_query <- function(corpus, query, subcorpus = "QUERY"){
-  stopifnot(corpus %in% cqp_list_corpora())
-  query <- check_cqp_query(query)
+  # stopifnot(corpus %in% cqp_list_corpora())
+  query <- check_query(query)
   .cqp_query(corpus = corpus, subcorpus = subcorpus, query = query)
 }
 
@@ -159,6 +155,62 @@ cqp_subcorpus_size <- function(corpus, subcorpus = "QUERY"){
 #' @rdname cqp_query
 cqp_list_subcorpora <- function(corpus){
   stopifnot(corpus %in% cqp_list_corpora())
-  .cqp_list_subcorpora(inCorpus = corpus)
+  sc <- .cqp_list_subcorpora(inCorpus = corpus)
+  # For technical reasons not yet well understood, we find "Last" on the 
+  # vector that is returned.
+  sc[-which(sc == "Last")]
 }
 
+#' @export cqp_drop_subcorpus
+#' @rdname cqp_query
+cqp_drop_subcorpus <- function(corpus){
+  # stopifnot(corpus %in% cqp_list_corpora())
+  .cqp_drop_subcorpus(inSubcorpus = corpus)
+}
+
+#' Get ranges of subcorpus
+#' 
+#' @param subcorpus_pointer A pointer (class `externalptr`) referencing a CWB
+#'   subcorpus.
+subcorpus_get_ranges <- function(subcorpus_pointer){
+  .cqp_subcorpus_regions(subcorpus_pointer)
+}
+
+#' Create CWB subcorpus from matrix with regions.
+#' 
+#' @param region_matrix A two-colum `matrix` with regions in rows: Start
+#'   position of region in first column, end position in second column.
+#' @param corpus A `externalptr` referencing a corpus such as generated by
+#'   `cl_find_corpus()`.
+#' @param subcorpus A length-one `character` vector providing the name for the
+#'   subcorpus.
+#' @examples
+#' \dontrun{
+#' # First we generate a subcorpus from a query result
+#' oil_context <- cqp_query("REUTERS", subcorpus = "OIL", query = '[]{3}"oil" []{3}')
+#' m <- subcorpus_get_ranges(oil_context)
+#' reuters <- cl_find_corpus("REUTERS", registry = get_tmp_registry())
+#' p <- matrix_to_subcorpus(subcorpus = "OIL2", corpus = reuters, region_matrix = m)
+#' cqp_list_subcorpora("REUTERS")
+#' 
+#' x <- cqp_query("REUTERS:OIL2", query = '"crude";', subcorpus = "CRUDEOIL")
+#' subcorpus_get_ranges(x)
+#' 
+#' # clean up
+#' cqp_drop_subcorpus("REUTERS:OIL")
+#' cqp_drop_subcorpus("REUTERS:OIL2")
+#' cqp_drop_subcorpus("REUTERS:CRUDEOIL")
+#' }
+matrix_to_subcorpus <- function(region_matrix, corpus, subcorpus){
+  .region_matrix_to_subcorpus(region_matrix = region_matrix, corpus = corpus, subcorpus = subcorpus)
+}
+
+
+#' @param corpus ID of a CWB corpus (length-one `character`).
+#' @details `cqp_load_corpus` will return a `logical` value - `TRUE` if corpus
+#'   has been loaded successfully, `FALSE` if not.
+#' @export cqp_load_corpus
+#' @rdname cqp_initialize
+cqp_load_corpus <- function(corpus, registry){
+  as.logical(.cqp_load_corpus(corpus = corpus, registry = registry))
+}
